"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class ChatInput(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _AcceptFile:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _AcceptFileEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[ChatInput._AcceptFile.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        NONE: ChatInput._AcceptFile.ValueType  # 0
        SINGLE: ChatInput._AcceptFile.ValueType  # 1
        MULTIPLE: ChatInput._AcceptFile.ValueType  # 2
        DIRECTORY: ChatInput._AcceptFile.ValueType  # 3

    class AcceptFile(_AcceptFile, metaclass=_AcceptFileEnumTypeWrapper): ...
    NONE: ChatInput.AcceptFile.ValueType  # 0
    SINGLE: ChatInput.AcceptFile.ValueType  # 1
    MULTIPLE: ChatInput.AcceptFile.ValueType  # 2
    DIRECTORY: ChatInput.AcceptFile.ValueType  # 3

    ID_FIELD_NUMBER: _builtins.int
    PLACEHOLDER_FIELD_NUMBER: _builtins.int
    MAX_CHARS_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    VALUE_FIELD_NUMBER: _builtins.int
    SET_VALUE_FIELD_NUMBER: _builtins.int
    DEFAULT_FIELD_NUMBER: _builtins.int
    ACCEPT_FILE_FIELD_NUMBER: _builtins.int
    FILE_TYPE_FIELD_NUMBER: _builtins.int
    MAX_UPLOAD_SIZE_MB_FIELD_NUMBER: _builtins.int
    ACCEPT_AUDIO_FIELD_NUMBER: _builtins.int
    AUDIO_SAMPLE_RATE_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    placeholder: _builtins.str
    max_chars: _builtins.int
    disabled: _builtins.bool
    value: _builtins.str
    set_value: _builtins.bool
    default: _builtins.str
    accept_file: Global___ChatInput.AcceptFile.ValueType
    max_upload_size_mb: _builtins.int
    """Max file size allowed by server config"""
    accept_audio: _builtins.bool
    """Whether to show audio recording button"""
    audio_sample_rate: _builtins.int
    """Sample rate for audio recording in Hz (e.g., 16000, 48000)
    If not set, uses browser default
    """
    @_builtins.property
    def file_type(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]:
        """Supported file types: For example: ["png","jpg","img"]"""

    def __init__(
        self,
        *,
        id: _builtins.str = ...,
        placeholder: _builtins.str = ...,
        max_chars: _builtins.int = ...,
        disabled: _builtins.bool = ...,
        value: _builtins.str = ...,
        set_value: _builtins.bool = ...,
        default: _builtins.str = ...,
        accept_file: Global___ChatInput.AcceptFile.ValueType = ...,
        file_type: _abc.Iterable[_builtins.str] | None = ...,
        max_upload_size_mb: _builtins.int = ...,
        accept_audio: _builtins.bool = ...,
        audio_sample_rate: _builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_audio_sample_rate", b"_audio_sample_rate", "audio_sample_rate", b"audio_sample_rate"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_audio_sample_rate", b"_audio_sample_rate", "accept_audio", b"accept_audio", "accept_file", b"accept_file", "audio_sample_rate", b"audio_sample_rate", "default", b"default", "disabled", b"disabled", "file_type", b"file_type", "id", b"id", "max_chars", b"max_chars", "max_upload_size_mb", b"max_upload_size_mb", "placeholder", b"placeholder", "set_value", b"set_value", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__audio_sample_rate: _TypeAlias = _typing.Literal["audio_sample_rate"]  # noqa: Y015
    _WhichOneofArgType__audio_sample_rate: _TypeAlias = _typing.Literal["_audio_sample_rate", b"_audio_sample_rate"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__audio_sample_rate) -> _WhichOneofReturnType__audio_sample_rate | None: ...

Global___ChatInput: _TypeAlias = ChatInput  # noqa: Y015
