"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PlotlyChart(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _SelectionMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SelectionModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PlotlyChart._SelectionMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        POINTS: PlotlyChart._SelectionMode.ValueType  # 0
        """Point selection mode"""
        BOX: PlotlyChart._SelectionMode.ValueType  # 1
        """Box selection mode"""
        LASSO: PlotlyChart._SelectionMode.ValueType  # 2
        """Lasso selection mode"""

    class SelectionMode(_SelectionMode, metaclass=_SelectionModeEnumTypeWrapper):
        """Available selection modes:"""

    POINTS: PlotlyChart.SelectionMode.ValueType  # 0
    """Point selection mode"""
    BOX: PlotlyChart.SelectionMode.ValueType  # 1
    """Box selection mode"""
    LASSO: PlotlyChart.SelectionMode.ValueType  # 2
    """Lasso selection mode"""

    THEME_FIELD_NUMBER: _builtins.int
    ID_FIELD_NUMBER: _builtins.int
    SELECTION_MODE_FIELD_NUMBER: _builtins.int
    FORM_ID_FIELD_NUMBER: _builtins.int
    SPEC_FIELD_NUMBER: _builtins.int
    CONFIG_FIELD_NUMBER: _builtins.int
    theme: _builtins.str
    """override the properties with a theme. Currently, only "streamlit" or None are accepted."""
    id: _builtins.str
    """The unique element ID of this chart."""
    form_id: _builtins.str
    """Form ID, filled if selections are activated."""
    spec: _builtins.str
    """JSON-serialized dict containing keys from the set {data, frames, layout}."""
    config: _builtins.str
    """JSON-serialized dict with Plotly's config object."""
    @_builtins.property
    def selection_mode(self) -> _containers.RepeatedScalarFieldContainer[Global___PlotlyChart.SelectionMode.ValueType]:
        """Activate selections types on the chart."""

    def __init__(
        self,
        *,
        theme: _builtins.str = ...,
        id: _builtins.str = ...,
        selection_mode: _abc.Iterable[Global___PlotlyChart.SelectionMode.ValueType] | None = ...,
        form_id: _builtins.str = ...,
        spec: _builtins.str = ...,
        config: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["config", b"config", "form_id", b"form_id", "id", b"id", "selection_mode", b"selection_mode", "spec", b"spec", "theme", b"theme"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PlotlyChart: _TypeAlias = PlotlyChart  # noqa: Y015
