"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class GitInfo(_message.Message):
    """Message used to update page metadata."""

    DESCRIPTOR: _descriptor.Descriptor

    class _GitStates:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GitStatesEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[GitInfo._GitStates.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DEFAULT: GitInfo._GitStates.ValueType  # 0
        HEAD_DETACHED: GitInfo._GitStates.ValueType  # 1
        AHEAD_OF_REMOTE: GitInfo._GitStates.ValueType  # 2

    class GitStates(_GitStates, metaclass=_GitStatesEnumTypeWrapper): ...
    DEFAULT: GitInfo.GitStates.ValueType  # 0
    HEAD_DETACHED: GitInfo.GitStates.ValueType  # 1
    AHEAD_OF_REMOTE: GitInfo.GitStates.ValueType  # 2

    REPOSITORY_FIELD_NUMBER: _builtins.int
    BRANCH_FIELD_NUMBER: _builtins.int
    MODULE_FIELD_NUMBER: _builtins.int
    UNTRACKED_FILES_FIELD_NUMBER: _builtins.int
    UNCOMMITTED_FILES_FIELD_NUMBER: _builtins.int
    STATE_FIELD_NUMBER: _builtins.int
    repository: _builtins.str
    branch: _builtins.str
    module: _builtins.str
    state: Global___GitInfo.GitStates.ValueType
    @_builtins.property
    def untracked_files(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
    @_builtins.property
    def uncommitted_files(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
    def __init__(
        self,
        *,
        repository: _builtins.str = ...,
        branch: _builtins.str = ...,
        module: _builtins.str = ...,
        untracked_files: _abc.Iterable[_builtins.str] | None = ...,
        uncommitted_files: _abc.Iterable[_builtins.str] | None = ...,
        state: Global___GitInfo.GitStates.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["branch", b"branch", "module", b"module", "repository", b"repository", "state", b"state", "uncommitted_files", b"uncommitted_files", "untracked_files", b"untracked_files"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GitInfo: _TypeAlias = GitInfo  # noqa: Y015
