"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import AppPage_pb2 as _AppPage_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Navigation(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _Position:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _PositionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Navigation._Position.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        HIDDEN: Navigation._Position.ValueType  # 0
        """do not display the navigation"""
        SIDEBAR: Navigation._Position.ValueType  # 1
        """display navigation in the sidebar"""
        TOP: Navigation._Position.ValueType  # 2
        """display navigation in the top header"""

    class Position(_Position, metaclass=_PositionEnumTypeWrapper):
        """Position of the Navigation"""

    HIDDEN: Navigation.Position.ValueType  # 0
    """do not display the navigation"""
    SIDEBAR: Navigation.Position.ValueType  # 1
    """display navigation in the sidebar"""
    TOP: Navigation.Position.ValueType  # 2
    """display navigation in the top header"""

    SECTIONS_FIELD_NUMBER: _builtins.int
    APP_PAGES_FIELD_NUMBER: _builtins.int
    POSITION_FIELD_NUMBER: _builtins.int
    PAGE_SCRIPT_HASH_FIELD_NUMBER: _builtins.int
    EXPANDED_FIELD_NUMBER: _builtins.int
    VISIBLE_ITEMS_FIELD_NUMBER: _builtins.int
    position: Global___Navigation.Position.ValueType
    page_script_hash: _builtins.str
    """The script hash for the page identified by st.navigation"""
    expanded: _builtins.bool
    visible_items: _builtins.int
    """Maximum number of pages to display when the navigation is collapsed.
    When not set, uses the default (10 pages).
    When set to a positive value, shows that many pages before "View X more".
    """
    @_builtins.property
    def sections(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
    @_builtins.property
    def app_pages(self) -> _containers.RepeatedCompositeFieldContainer[_AppPage_pb2.AppPage]: ...
    def __init__(
        self,
        *,
        sections: _abc.Iterable[_builtins.str] | None = ...,
        app_pages: _abc.Iterable[_AppPage_pb2.AppPage] | None = ...,
        position: Global___Navigation.Position.ValueType = ...,
        page_script_hash: _builtins.str = ...,
        expanded: _builtins.bool = ...,
        visible_items: _builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_visible_items", b"_visible_items", "visible_items", b"visible_items"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_visible_items", b"_visible_items", "app_pages", b"app_pages", "expanded", b"expanded", "page_script_hash", b"page_script_hash", "position", b"position", "sections", b"sections", "visible_items", b"visible_items"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__visible_items: _TypeAlias = _typing.Literal["visible_items"]  # noqa: Y015
    _WhichOneofArgType__visible_items: _TypeAlias = _typing.Literal["_visible_items", b"_visible_items"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__visible_items) -> _WhichOneofReturnType__visible_items | None: ...

Global___Navigation: _TypeAlias = Navigation  # noqa: Y015
