"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import WidthConfig_pb2 as _WidthConfig_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class SubtitleTrack(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    LABEL_FIELD_NUMBER: _builtins.int
    URL_FIELD_NUMBER: _builtins.int
    label: _builtins.str
    """Label for the subtitle e.g. "English" or "Spanish"."""
    url: _builtins.str
    def __init__(
        self,
        *,
        label: _builtins.str = ...,
        url: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["label", b"label", "url", b"url"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SubtitleTrack: _TypeAlias = SubtitleTrack  # noqa: Y015

@_typing.final
class Video(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _Type:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _TypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Video._Type.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        UNUSED: Video._Type.ValueType  # 0
        """This should always exist."""
        NATIVE: Video._Type.ValueType  # 1
        YOUTUBE_IFRAME: Video._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNUSED: Video.Type.ValueType  # 0
    """This should always exist."""
    NATIVE: Video.Type.ValueType  # 1
    YOUTUBE_IFRAME: Video.Type.ValueType  # 2

    URL_FIELD_NUMBER: _builtins.int
    START_TIME_FIELD_NUMBER: _builtins.int
    TYPE_FIELD_NUMBER: _builtins.int
    SUBTITLES_FIELD_NUMBER: _builtins.int
    END_TIME_FIELD_NUMBER: _builtins.int
    LOOP_FIELD_NUMBER: _builtins.int
    AUTOPLAY_FIELD_NUMBER: _builtins.int
    MUTED_FIELD_NUMBER: _builtins.int
    ID_FIELD_NUMBER: _builtins.int
    WIDTH_CONFIG_FIELD_NUMBER: _builtins.int
    url: _builtins.str
    """A url pointing to a video file"""
    start_time: _builtins.int
    """The currentTime attribute of the HTML <video> tag's <source> subtag."""
    type: Global___Video.Type.ValueType
    """Type affects how browser wraps the video in tags: plain HTML5, YouTube..."""
    end_time: _builtins.int
    """The time at which the video should stop playing. If not specified, plays to the end."""
    loop: _builtins.bool
    """Indicates whether the video should start over from the beginning once it ends."""
    autoplay: _builtins.bool
    muted: _builtins.bool
    id: _builtins.str
    @_builtins.property
    def subtitles(self) -> _containers.RepeatedCompositeFieldContainer[Global___SubtitleTrack]:
        """Repeated field for subtitle tracks"""

    @_builtins.property
    def width_config(self) -> _WidthConfig_pb2.WidthConfig: ...
    def __init__(
        self,
        *,
        url: _builtins.str = ...,
        start_time: _builtins.int = ...,
        type: Global___Video.Type.ValueType = ...,
        subtitles: _abc.Iterable[Global___SubtitleTrack] | None = ...,
        end_time: _builtins.int = ...,
        loop: _builtins.bool = ...,
        autoplay: _builtins.bool = ...,
        muted: _builtins.bool = ...,
        id: _builtins.str = ...,
        width_config: _WidthConfig_pb2.WidthConfig | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_width_config", b"_width_config", "width_config", b"width_config"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_width_config", b"_width_config", "autoplay", b"autoplay", "end_time", b"end_time", "id", b"id", "loop", b"loop", "muted", b"muted", "start_time", b"start_time", "subtitles", b"subtitles", "type", b"type", "url", b"url", "width_config", b"width_config"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__width_config: _TypeAlias = _typing.Literal["width_config"]  # noqa: Y015
    _WhichOneofArgType__width_config: _TypeAlias = _typing.Literal["_width_config", b"_width_config"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__width_config) -> _WhichOneofReturnType__width_config | None: ...

Global___Video: _TypeAlias = Video  # noqa: Y015
