"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import LabelVisibility_pb2 as _LabelVisibility_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Metric(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _MetricDirection:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _MetricDirectionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Metric._MetricDirection.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DOWN: Metric._MetricDirection.ValueType  # 0
        UP: Metric._MetricDirection.ValueType  # 1
        NONE: Metric._MetricDirection.ValueType  # 2

    class MetricDirection(_MetricDirection, metaclass=_MetricDirectionEnumTypeWrapper): ...
    DOWN: Metric.MetricDirection.ValueType  # 0
    UP: Metric.MetricDirection.ValueType  # 1
    NONE: Metric.MetricDirection.ValueType  # 2

    class _MetricColor:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _MetricColorEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Metric._MetricColor.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        RED: Metric._MetricColor.ValueType  # 0
        GREEN: Metric._MetricColor.ValueType  # 1
        GRAY: Metric._MetricColor.ValueType  # 2
        ORANGE: Metric._MetricColor.ValueType  # 3
        YELLOW: Metric._MetricColor.ValueType  # 4
        BLUE: Metric._MetricColor.ValueType  # 5
        VIOLET: Metric._MetricColor.ValueType  # 6
        PRIMARY: Metric._MetricColor.ValueType  # 7

    class MetricColor(_MetricColor, metaclass=_MetricColorEnumTypeWrapper): ...
    RED: Metric.MetricColor.ValueType  # 0
    GREEN: Metric.MetricColor.ValueType  # 1
    GRAY: Metric.MetricColor.ValueType  # 2
    ORANGE: Metric.MetricColor.ValueType  # 3
    YELLOW: Metric.MetricColor.ValueType  # 4
    BLUE: Metric.MetricColor.ValueType  # 5
    VIOLET: Metric.MetricColor.ValueType  # 6
    PRIMARY: Metric.MetricColor.ValueType  # 7

    class _ChartType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ChartTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Metric._ChartType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        LINE: Metric._ChartType.ValueType  # 0
        BAR: Metric._ChartType.ValueType  # 1
        AREA: Metric._ChartType.ValueType  # 2

    class ChartType(_ChartType, metaclass=_ChartTypeEnumTypeWrapper): ...
    LINE: Metric.ChartType.ValueType  # 0
    BAR: Metric.ChartType.ValueType  # 1
    AREA: Metric.ChartType.ValueType  # 2

    LABEL_FIELD_NUMBER: _builtins.int
    BODY_FIELD_NUMBER: _builtins.int
    DELTA_FIELD_NUMBER: _builtins.int
    DIRECTION_FIELD_NUMBER: _builtins.int
    COLOR_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    LABEL_VISIBILITY_FIELD_NUMBER: _builtins.int
    SHOW_BORDER_FIELD_NUMBER: _builtins.int
    CHART_DATA_FIELD_NUMBER: _builtins.int
    CHART_TYPE_FIELD_NUMBER: _builtins.int
    FORMAT_FIELD_NUMBER: _builtins.int
    DELTA_DESCRIPTION_FIELD_NUMBER: _builtins.int
    label: _builtins.str
    body: _builtins.str
    delta: _builtins.str
    direction: Global___Metric.MetricDirection.ValueType
    color: Global___Metric.MetricColor.ValueType
    help: _builtins.str
    show_border: _builtins.bool
    chart_type: Global___Metric.ChartType.ValueType
    format: _builtins.str
    """Format string for the value and delta (applied only if they are numeric)."""
    delta_description: _builtins.str
    """Optional description text to display next to the delta value."""
    @_builtins.property
    def label_visibility(self) -> _LabelVisibility_pb2.LabelVisibility: ...
    @_builtins.property
    def chart_data(self) -> _containers.RepeatedScalarFieldContainer[_builtins.float]: ...
    def __init__(
        self,
        *,
        label: _builtins.str = ...,
        body: _builtins.str = ...,
        delta: _builtins.str = ...,
        direction: Global___Metric.MetricDirection.ValueType = ...,
        color: Global___Metric.MetricColor.ValueType = ...,
        help: _builtins.str = ...,
        label_visibility: _LabelVisibility_pb2.LabelVisibility | None = ...,
        show_border: _builtins.bool = ...,
        chart_data: _abc.Iterable[_builtins.float] | None = ...,
        chart_type: Global___Metric.ChartType.ValueType = ...,
        format: _builtins.str = ...,
        delta_description: _builtins.str = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["label_visibility", b"label_visibility"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body", "chart_data", b"chart_data", "chart_type", b"chart_type", "color", b"color", "delta", b"delta", "delta_description", b"delta_description", "direction", b"direction", "format", b"format", "help", b"help", "label", b"label", "label_visibility", b"label_visibility", "show_border", b"show_border"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Metric: _TypeAlias = Metric  # noqa: Y015
