"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from streamlit.proto import ButtonLikeIconPosition_pb2 as _ButtonLikeIconPosition_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class LinkButton(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    ID_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    URL_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    USE_CONTAINER_WIDTH_FIELD_NUMBER: _builtins.int
    TYPE_FIELD_NUMBER: _builtins.int
    ICON_FIELD_NUMBER: _builtins.int
    SHORTCUT_FIELD_NUMBER: _builtins.int
    ICON_POSITION_FIELD_NUMBER: _builtins.int
    IGNORE_RERUN_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    """The ID is needed for shortcuts, keys, and click-triggered reruns."""
    label: _builtins.str
    help: _builtins.str
    url: _builtins.str
    disabled: _builtins.bool
    use_container_width: _builtins.bool
    type: _builtins.str
    icon: _builtins.str
    shortcut: _builtins.str
    icon_position: _ButtonLikeIconPosition_pb2.ButtonLikeIconPosition.ValueType
    ignore_rerun: _builtins.bool
    def __init__(
        self,
        *,
        id: _builtins.str = ...,
        label: _builtins.str = ...,
        help: _builtins.str = ...,
        url: _builtins.str = ...,
        disabled: _builtins.bool = ...,
        use_container_width: _builtins.bool = ...,
        type: _builtins.str = ...,
        icon: _builtins.str = ...,
        shortcut: _builtins.str = ...,
        icon_position: _ButtonLikeIconPosition_pb2.ButtonLikeIconPosition.ValueType = ...,
        ignore_rerun: _builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["disabled", b"disabled", "help", b"help", "icon", b"icon", "icon_position", b"icon_position", "id", b"id", "ignore_rerun", b"ignore_rerun", "label", b"label", "shortcut", b"shortcut", "type", b"type", "url", b"url", "use_container_width", b"use_container_width"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LinkButton: _TypeAlias = LinkButton  # noqa: Y015
