"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from streamlit.proto import WidgetStates_pb2 as _WidgetStates_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class ContextInfo(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    TIMEZONE_FIELD_NUMBER: _builtins.int
    TIMEZONE_OFFSET_FIELD_NUMBER: _builtins.int
    LOCALE_FIELD_NUMBER: _builtins.int
    URL_FIELD_NUMBER: _builtins.int
    IS_EMBEDDED_FIELD_NUMBER: _builtins.int
    COLOR_SCHEME_FIELD_NUMBER: _builtins.int
    timezone: _builtins.str
    timezone_offset: _builtins.int
    locale: _builtins.str
    url: _builtins.str
    is_embedded: _builtins.bool
    color_scheme: _builtins.str
    def __init__(
        self,
        *,
        timezone: _builtins.str | None = ...,
        timezone_offset: _builtins.int | None = ...,
        locale: _builtins.str | None = ...,
        url: _builtins.str | None = ...,
        is_embedded: _builtins.bool | None = ...,
        color_scheme: _builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_color_scheme", b"_color_scheme", "_is_embedded", b"_is_embedded", "_locale", b"_locale", "_timezone", b"_timezone", "_timezone_offset", b"_timezone_offset", "_url", b"_url", "color_scheme", b"color_scheme", "is_embedded", b"is_embedded", "locale", b"locale", "timezone", b"timezone", "timezone_offset", b"timezone_offset", "url", b"url"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_color_scheme", b"_color_scheme", "_is_embedded", b"_is_embedded", "_locale", b"_locale", "_timezone", b"_timezone", "_timezone_offset", b"_timezone_offset", "_url", b"_url", "color_scheme", b"color_scheme", "is_embedded", b"is_embedded", "locale", b"locale", "timezone", b"timezone", "timezone_offset", b"timezone_offset", "url", b"url"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__color_scheme: _TypeAlias = _typing.Literal["color_scheme"]  # noqa: Y015
    _WhichOneofArgType__color_scheme: _TypeAlias = _typing.Literal["_color_scheme", b"_color_scheme"]  # noqa: Y015
    _WhichOneofReturnType__is_embedded: _TypeAlias = _typing.Literal["is_embedded"]  # noqa: Y015
    _WhichOneofArgType__is_embedded: _TypeAlias = _typing.Literal["_is_embedded", b"_is_embedded"]  # noqa: Y015
    _WhichOneofReturnType__locale: _TypeAlias = _typing.Literal["locale"]  # noqa: Y015
    _WhichOneofArgType__locale: _TypeAlias = _typing.Literal["_locale", b"_locale"]  # noqa: Y015
    _WhichOneofReturnType__timezone: _TypeAlias = _typing.Literal["timezone"]  # noqa: Y015
    _WhichOneofArgType__timezone: _TypeAlias = _typing.Literal["_timezone", b"_timezone"]  # noqa: Y015
    _WhichOneofReturnType__timezone_offset: _TypeAlias = _typing.Literal["timezone_offset"]  # noqa: Y015
    _WhichOneofArgType__timezone_offset: _TypeAlias = _typing.Literal["_timezone_offset", b"_timezone_offset"]  # noqa: Y015
    _WhichOneofReturnType__url: _TypeAlias = _typing.Literal["url"]  # noqa: Y015
    _WhichOneofArgType__url: _TypeAlias = _typing.Literal["_url", b"_url"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__color_scheme) -> _WhichOneofReturnType__color_scheme | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__is_embedded) -> _WhichOneofReturnType__is_embedded | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__locale) -> _WhichOneofReturnType__locale | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__timezone) -> _WhichOneofReturnType__timezone | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__timezone_offset) -> _WhichOneofReturnType__timezone_offset | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__url) -> _WhichOneofReturnType__url | None: ...

Global___ContextInfo: _TypeAlias = ContextInfo  # noqa: Y015

@_typing.final
class ClientState(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    QUERY_STRING_FIELD_NUMBER: _builtins.int
    WIDGET_STATES_FIELD_NUMBER: _builtins.int
    PAGE_SCRIPT_HASH_FIELD_NUMBER: _builtins.int
    PAGE_NAME_FIELD_NUMBER: _builtins.int
    FRAGMENT_ID_FIELD_NUMBER: _builtins.int
    IS_AUTO_RERUN_FIELD_NUMBER: _builtins.int
    CACHED_MESSAGE_HASHES_FIELD_NUMBER: _builtins.int
    CONTEXT_INFO_FIELD_NUMBER: _builtins.int
    query_string: _builtins.str
    page_script_hash: _builtins.str
    page_name: _builtins.str
    fragment_id: _builtins.str
    is_auto_rerun: _builtins.bool
    @_builtins.property
    def widget_states(self) -> _WidgetStates_pb2.WidgetStates: ...
    @_builtins.property
    def cached_message_hashes(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]:
        """List of hashes of messages that are currently cached in
        the frontend forward message cache.
        """

    @_builtins.property
    def context_info(self) -> Global___ContextInfo: ...
    def __init__(
        self,
        *,
        query_string: _builtins.str = ...,
        widget_states: _WidgetStates_pb2.WidgetStates | None = ...,
        page_script_hash: _builtins.str = ...,
        page_name: _builtins.str = ...,
        fragment_id: _builtins.str = ...,
        is_auto_rerun: _builtins.bool = ...,
        cached_message_hashes: _abc.Iterable[_builtins.str] | None = ...,
        context_info: Global___ContextInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["context_info", b"context_info", "widget_states", b"widget_states"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["cached_message_hashes", b"cached_message_hashes", "context_info", b"context_info", "fragment_id", b"fragment_id", "is_auto_rerun", b"is_auto_rerun", "page_name", b"page_name", "page_script_hash", b"page_script_hash", "query_string", b"query_string", "widget_states", b"widget_states"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ClientState: _TypeAlias = ClientState  # noqa: Y015
