"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Image(_message.Message):
    """An image which can be displayed on the screen."""

    DESCRIPTOR: _descriptor.Descriptor

    URL_FIELD_NUMBER: _builtins.int
    CAPTION_FIELD_NUMBER: _builtins.int
    url: _builtins.str
    caption: _builtins.str
    def __init__(
        self,
        *,
        url: _builtins.str = ...,
        caption: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["caption", b"caption", "url", b"url"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Image: _TypeAlias = Image  # noqa: Y015

@_typing.final
class ImageList(_message.Message):
    """A set of images."""

    DESCRIPTOR: _descriptor.Descriptor

    IMGS_FIELD_NUMBER: _builtins.int
    LINK_FIELD_NUMBER: _builtins.int
    link: _builtins.str
    """External URL to open when the image is clicked.
    Only supported when there is exactly one image in the list.
    """
    @_builtins.property
    def imgs(self) -> _containers.RepeatedCompositeFieldContainer[Global___Image]: ...
    def __init__(
        self,
        *,
        imgs: _abc.Iterable[Global___Image] | None = ...,
        link: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["imgs", b"imgs", "link", b"link"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ImageList: _TypeAlias = ImageList  # noqa: Y015
