"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class DeckGlJsonChart(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _SelectionMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SelectionModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[DeckGlJsonChart._SelectionMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SINGLE_OBJECT: DeckGlJsonChart._SelectionMode.ValueType  # 0
        """Only one object can be selected at a time."""
        MULTI_OBJECT: DeckGlJsonChart._SelectionMode.ValueType  # 1
        """Multiple objects can be selected at a time."""

    class SelectionMode(_SelectionMode, metaclass=_SelectionModeEnumTypeWrapper):
        """Available selection modes:"""

    SINGLE_OBJECT: DeckGlJsonChart.SelectionMode.ValueType  # 0
    """Only one object can be selected at a time."""
    MULTI_OBJECT: DeckGlJsonChart.SelectionMode.ValueType  # 1
    """Multiple objects can be selected at a time."""

    JSON_FIELD_NUMBER: _builtins.int
    TOOLTIP_FIELD_NUMBER: _builtins.int
    ID_FIELD_NUMBER: _builtins.int
    MAPBOX_TOKEN_FIELD_NUMBER: _builtins.int
    SELECTION_MODE_FIELD_NUMBER: _builtins.int
    FORM_ID_FIELD_NUMBER: _builtins.int
    json: _builtins.str
    """The json of the pydeck object (https://deckgl.readthedocs.io/en/latest/deck.html)"""
    tooltip: _builtins.str
    id: _builtins.str
    """ID, required for selection events."""
    mapbox_token: _builtins.str
    """The Mapbox token, if any."""
    form_id: _builtins.str
    """The form ID of the widget, this is required if the chart has selection events"""
    @_builtins.property
    def selection_mode(self) -> _containers.RepeatedScalarFieldContainer[Global___DeckGlJsonChart.SelectionMode.ValueType]:
        """If non-empty, treat this instance as a Widget"""

    def __init__(
        self,
        *,
        json: _builtins.str = ...,
        tooltip: _builtins.str = ...,
        id: _builtins.str = ...,
        mapbox_token: _builtins.str = ...,
        selection_mode: _abc.Iterable[Global___DeckGlJsonChart.SelectionMode.ValueType] | None = ...,
        form_id: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["form_id", b"form_id", "id", b"id", "json", b"json", "mapbox_token", b"mapbox_token", "selection_mode", b"selection_mode", "tooltip", b"tooltip"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeckGlJsonChart: _TypeAlias = DeckGlJsonChart  # noqa: Y015
