"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Json(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    BODY_FIELD_NUMBER: _builtins.int
    EXPANDED_FIELD_NUMBER: _builtins.int
    MAX_EXPAND_DEPTH_FIELD_NUMBER: _builtins.int
    body: _builtins.str
    """Content to display."""
    expanded: _builtins.bool
    """Controls the initial expansion state of the json element.
    Is superseded by max_expand_depth if provided.
    """
    max_expand_depth: _builtins.int
    """The maximum depth to expand the JSON object."""
    def __init__(
        self,
        *,
        body: _builtins.str = ...,
        expanded: _builtins.bool = ...,
        max_expand_depth: _builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_max_expand_depth", b"_max_expand_depth", "max_expand_depth", b"max_expand_depth"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_max_expand_depth", b"_max_expand_depth", "body", b"body", "expanded", b"expanded", "max_expand_depth", b"max_expand_depth"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__max_expand_depth: _TypeAlias = _typing.Literal["max_expand_depth"]  # noqa: Y015
    _WhichOneofArgType__max_expand_depth: _TypeAlias = _typing.Literal["_max_expand_depth", b"_max_expand_depth"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__max_expand_depth) -> _WhichOneofReturnType__max_expand_depth | None: ...

Global___Json: _TypeAlias = Json  # noqa: Y015
