"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from streamlit.proto import ButtonLikeIconPosition_pb2 as _ButtonLikeIconPosition_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PageLink(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    PAGE_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    ICON_FIELD_NUMBER: _builtins.int
    PAGE_SCRIPT_HASH_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    USE_CONTAINER_WIDTH_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    EXTERNAL_FIELD_NUMBER: _builtins.int
    QUERY_STRING_FIELD_NUMBER: _builtins.int
    ICON_POSITION_FIELD_NUMBER: _builtins.int
    page: _builtins.str
    label: _builtins.str
    icon: _builtins.str
    page_script_hash: _builtins.str
    help: _builtins.str
    use_container_width: _builtins.bool
    disabled: _builtins.bool
    external: _builtins.bool
    query_string: _builtins.str
    icon_position: _ButtonLikeIconPosition_pb2.ButtonLikeIconPosition.ValueType
    def __init__(
        self,
        *,
        page: _builtins.str = ...,
        label: _builtins.str = ...,
        icon: _builtins.str = ...,
        page_script_hash: _builtins.str = ...,
        help: _builtins.str = ...,
        use_container_width: _builtins.bool | None = ...,
        disabled: _builtins.bool = ...,
        external: _builtins.bool = ...,
        query_string: _builtins.str = ...,
        icon_position: _ButtonLikeIconPosition_pb2.ButtonLikeIconPosition.ValueType = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_use_container_width", b"_use_container_width", "use_container_width", b"use_container_width"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_use_container_width", b"_use_container_width", "disabled", b"disabled", "external", b"external", "help", b"help", "icon", b"icon", "icon_position", b"icon_position", "label", b"label", "page", b"page", "page_script_hash", b"page_script_hash", "query_string", b"query_string", "use_container_width", b"use_container_width"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__use_container_width: _TypeAlias = _typing.Literal["use_container_width"]  # noqa: Y015
    _WhichOneofArgType__use_container_width: _TypeAlias = _typing.Literal["_use_container_width", b"_use_container_width"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__use_container_width) -> _WhichOneofReturnType__use_container_width | None: ...

Global___PageLink: _TypeAlias = PageLink  # noqa: Y015
