import{o as e}from"./chunk.DuxOD-Sk.js";import{r as t}from"./emotion-is-prop-valid.esm.DV_OErv-.js";import{c as n,t as r}from"./emotion-styled.browser.esm.CEYoudG7.js";import{$ as i,Q as a}from"./protobuf.GnXEZo24.js";import"./utils.C1Nidt8_.js";import{n as o,t as s}from"./IFrameUtil.CiJyrZfZ.js";var c=e(t()),l=r(`iframe`,{target:`eu9re3w0`})(({theme:e,disableScrolling:t})=>({width:`100%`,height:`100%`,colorScheme:`normal`,border:`none`,padding:e.spacing.none,margin:e.spacing.none,overflow:t?`hidden`:void 0}));function u(e){return a(e)||e===``?void 0:e}function d({element:e}){let t=u(e.src),r=i(t)?void 0:u(e.srcdoc);return n(l,{className:`stIFrame`,"data-testid":`stIFrame`,allow:s,disableScrolling:!e.scrolling,src:t,srcDoc:r,scrolling:e.scrolling?`auto`:`no`,sandbox:o,title:`st.iframe`,tabIndex:e.tabIndex??void 0})}var f=(0,c.memo)(d);export{f as default};