"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PageConfig(_message.Message):
    """Properties of the page that the app creator may configure."""

    DESCRIPTOR: _descriptor.Descriptor

    class _Layout:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _LayoutEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PageConfig._Layout.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        CENTERED: PageConfig._Layout.ValueType  # 0
        """Render page elements in a centered block, roughly 730px wide."""
        WIDE: PageConfig._Layout.ValueType  # 1
        """Use the full browser width to render elements."""
        LAYOUT_UNSET: PageConfig._Layout.ValueType  # 2
        """Unset distinguishes that config was not provided - on initial call, will
        set to centered as default. Otherwise, inherit value from previous call
        """

    class Layout(_Layout, metaclass=_LayoutEnumTypeWrapper): ...
    CENTERED: PageConfig.Layout.ValueType  # 0
    """Render page elements in a centered block, roughly 730px wide."""
    WIDE: PageConfig.Layout.ValueType  # 1
    """Use the full browser width to render elements."""
    LAYOUT_UNSET: PageConfig.Layout.ValueType  # 2
    """Unset distinguishes that config was not provided - on initial call, will
    set to centered as default. Otherwise, inherit value from previous call
    """

    class _SidebarState:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SidebarStateEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PageConfig._SidebarState.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        AUTO: PageConfig._SidebarState.ValueType  # 0
        """Expand the sidebar if page width exceeds ~1000px; otherwise, collapse it"""
        EXPANDED: PageConfig._SidebarState.ValueType  # 1
        """Force the sidebar to be shown."""
        COLLAPSED: PageConfig._SidebarState.ValueType  # 2
        """Force the sidebar to be hidden."""
        SIDEBAR_UNSET: PageConfig._SidebarState.ValueType  # 3
        """Unset distinguishes that config was not provided - on initial call, will
        set to auto as default. Otherwise, inherit value from previous call
        """

    class SidebarState(_SidebarState, metaclass=_SidebarStateEnumTypeWrapper): ...
    AUTO: PageConfig.SidebarState.ValueType  # 0
    """Expand the sidebar if page width exceeds ~1000px; otherwise, collapse it"""
    EXPANDED: PageConfig.SidebarState.ValueType  # 1
    """Force the sidebar to be shown."""
    COLLAPSED: PageConfig.SidebarState.ValueType  # 2
    """Force the sidebar to be hidden."""
    SIDEBAR_UNSET: PageConfig.SidebarState.ValueType  # 3
    """Unset distinguishes that config was not provided - on initial call, will
    set to auto as default. Otherwise, inherit value from previous call
    """

    @_typing.final
    class MenuItems(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        GET_HELP_URL_FIELD_NUMBER: _builtins.int
        HIDE_GET_HELP_FIELD_NUMBER: _builtins.int
        REPORT_A_BUG_URL_FIELD_NUMBER: _builtins.int
        HIDE_REPORT_A_BUG_FIELD_NUMBER: _builtins.int
        ABOUT_SECTION_MD_FIELD_NUMBER: _builtins.int
        CLEAR_ABOUT_MD_FIELD_NUMBER: _builtins.int
        get_help_url: _builtins.str
        hide_get_help: _builtins.bool
        report_a_bug_url: _builtins.str
        hide_report_a_bug: _builtins.bool
        about_section_md: _builtins.str
        clear_about_md: _builtins.bool
        """For multiple calls to set_page_config, clears set about markdown"""
        def __init__(
            self,
            *,
            get_help_url: _builtins.str = ...,
            hide_get_help: _builtins.bool = ...,
            report_a_bug_url: _builtins.str = ...,
            hide_report_a_bug: _builtins.bool = ...,
            about_section_md: _builtins.str = ...,
            clear_about_md: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["about_section_md", b"about_section_md", "clear_about_md", b"clear_about_md", "get_help_url", b"get_help_url", "hide_get_help", b"hide_get_help", "hide_report_a_bug", b"hide_report_a_bug", "report_a_bug_url", b"report_a_bug_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SidebarWidthConfig(_message.Message):
        """Configuration for the initial sidebar width.
        Uses a oneof pattern to allow for future extensions (e.g., rem units).
        """

        DESCRIPTOR: _descriptor.Descriptor

        PIXEL_WIDTH_FIELD_NUMBER: _builtins.int
        pixel_width: _builtins.int
        def __init__(
            self,
            *,
            pixel_width: _builtins.int = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["pixel_width", b"pixel_width", "width_spec", b"width_spec"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["pixel_width", b"pixel_width", "width_spec", b"width_spec"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType_width_spec: _TypeAlias = _typing.Literal["pixel_width"]  # noqa: Y015
        _WhichOneofArgType_width_spec: _TypeAlias = _typing.Literal["width_spec", b"width_spec"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType_width_spec) -> _WhichOneofReturnType_width_spec | None: ...

    TITLE_FIELD_NUMBER: _builtins.int
    FAVICON_FIELD_NUMBER: _builtins.int
    LAYOUT_FIELD_NUMBER: _builtins.int
    INITIAL_SIDEBAR_STATE_FIELD_NUMBER: _builtins.int
    MENU_ITEMS_FIELD_NUMBER: _builtins.int
    INITIAL_SIDEBAR_WIDTH_FIELD_NUMBER: _builtins.int
    title: _builtins.str
    favicon: _builtins.str
    layout: Global___PageConfig.Layout.ValueType
    initial_sidebar_state: Global___PageConfig.SidebarState.ValueType
    @_builtins.property
    def menu_items(self) -> Global___PageConfig.MenuItems: ...
    @_builtins.property
    def initial_sidebar_width(self) -> Global___PageConfig.SidebarWidthConfig: ...
    def __init__(
        self,
        *,
        title: _builtins.str = ...,
        favicon: _builtins.str = ...,
        layout: Global___PageConfig.Layout.ValueType = ...,
        initial_sidebar_state: Global___PageConfig.SidebarState.ValueType = ...,
        menu_items: Global___PageConfig.MenuItems | None = ...,
        initial_sidebar_width: Global___PageConfig.SidebarWidthConfig | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_initial_sidebar_width", b"_initial_sidebar_width", "initial_sidebar_width", b"initial_sidebar_width", "menu_items", b"menu_items"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_initial_sidebar_width", b"_initial_sidebar_width", "favicon", b"favicon", "initial_sidebar_state", b"initial_sidebar_state", "initial_sidebar_width", b"initial_sidebar_width", "layout", b"layout", "menu_items", b"menu_items", "title", b"title"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__initial_sidebar_width: _TypeAlias = _typing.Literal["initial_sidebar_width"]  # noqa: Y015
    _WhichOneofArgType__initial_sidebar_width: _TypeAlias = _typing.Literal["_initial_sidebar_width", b"_initial_sidebar_width"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__initial_sidebar_width) -> _WhichOneofReturnType__initial_sidebar_width | None: ...

Global___PageConfig: _TypeAlias = PageConfig  # noqa: Y015
