"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Logo(_message.Message):
    """Handle the logo for an app"""

    DESCRIPTOR: _descriptor.Descriptor

    class _ImageType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ImageTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Logo._ImageType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        IMAGE: Logo._ImageType.ValueType  # 0
        EMOJI: Logo._ImageType.ValueType  # 1
        ICON: Logo._ImageType.ValueType  # 2

    class ImageType(_ImageType, metaclass=_ImageTypeEnumTypeWrapper):
        """Type of the logo image (image file, emoji, or material icon)"""

    IMAGE: Logo.ImageType.ValueType  # 0
    EMOJI: Logo.ImageType.ValueType  # 1
    ICON: Logo.ImageType.ValueType  # 2

    IMAGE_FIELD_NUMBER: _builtins.int
    LINK_FIELD_NUMBER: _builtins.int
    ICON_IMAGE_FIELD_NUMBER: _builtins.int
    SIZE_FIELD_NUMBER: _builtins.int
    IMAGE_TYPE_FIELD_NUMBER: _builtins.int
    ICON_IMAGE_TYPE_FIELD_NUMBER: _builtins.int
    image: _builtins.str
    link: _builtins.str
    icon_image: _builtins.str
    size: _builtins.str
    image_type: Global___Logo.ImageType.ValueType
    icon_image_type: Global___Logo.ImageType.ValueType
    def __init__(
        self,
        *,
        image: _builtins.str = ...,
        link: _builtins.str = ...,
        icon_image: _builtins.str = ...,
        size: _builtins.str = ...,
        image_type: Global___Logo.ImageType.ValueType = ...,
        icon_image_type: Global___Logo.ImageType.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["icon_image", b"icon_image", "icon_image_type", b"icon_image_type", "image", b"image", "image_type", b"image_type", "link", b"link", "size", b"size"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Logo: _TypeAlias = Logo  # noqa: Y015
