"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Toast(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    BODY_FIELD_NUMBER: _builtins.int
    ICON_FIELD_NUMBER: _builtins.int
    DURATION_FIELD_NUMBER: _builtins.int
    body: _builtins.str
    """Display message"""
    icon: _builtins.str
    """Emoji"""
    duration: _builtins.int
    """The time to display the toast message in seconds.
    If not set, the toast will be displayed for 4 seconds. A value of 0
    indicates that the toast should not be automatically dismissed.
    """
    def __init__(
        self,
        *,
        body: _builtins.str = ...,
        icon: _builtins.str = ...,
        duration: _builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_duration", b"_duration", "duration", b"duration"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_duration", b"_duration", "body", b"body", "duration", b"duration", "icon", b"icon"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__duration: _TypeAlias = _typing.Literal["duration"]  # noqa: Y015
    _WhichOneofArgType__duration: _TypeAlias = _typing.Literal["_duration", b"_duration"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType__duration) -> _WhichOneofReturnType__duration | None: ...

Global___Toast: _TypeAlias = Toast  # noqa: Y015
