"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import WidthConfig_pb2 as _WidthConfig_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Alert(_message.Message):
    """NOTE: This proto type is used by some external services so needs to remain
    relatively stable. While it isn't entirely set in stone, changing it
    may require a good amount of effort so should be avoided if possible.
    """

    DESCRIPTOR: _descriptor.Descriptor

    class _Format:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _FormatEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Alert._Format.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        UNUSED: Alert._Format.ValueType  # 0
        """Plain, fixed width text."""
        ERROR: Alert._Format.ValueType  # 1
        """Shows an error message."""
        WARNING: Alert._Format.ValueType  # 2
        """Shows a warning message."""
        INFO: Alert._Format.ValueType  # 3
        """Shows an info log."""
        SUCCESS: Alert._Format.ValueType  # 4
        """Shows a success message."""

    class Format(_Format, metaclass=_FormatEnumTypeWrapper):
        """Type of Alert"""

    UNUSED: Alert.Format.ValueType  # 0
    """Plain, fixed width text."""
    ERROR: Alert.Format.ValueType  # 1
    """Shows an error message."""
    WARNING: Alert.Format.ValueType  # 2
    """Shows a warning message."""
    INFO: Alert.Format.ValueType  # 3
    """Shows an info log."""
    SUCCESS: Alert.Format.ValueType  # 4
    """Shows a success message."""

    BODY_FIELD_NUMBER: _builtins.int
    FORMAT_FIELD_NUMBER: _builtins.int
    ICON_FIELD_NUMBER: _builtins.int
    WIDTH_CONFIG_FIELD_NUMBER: _builtins.int
    body: _builtins.str
    """Content to display."""
    format: Global___Alert.Format.ValueType
    icon: _builtins.str
    @_builtins.property
    def width_config(self) -> _WidthConfig_pb2.WidthConfig:
        """Indicates the width setting: "stetch", "content" or a pixel value."""

    def __init__(
        self,
        *,
        body: _builtins.str = ...,
        format: Global___Alert.Format.ValueType = ...,
        icon: _builtins.str = ...,
        width_config: _WidthConfig_pb2.WidthConfig | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["width_config", b"width_config"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body", "format", b"format", "icon", b"icon", "width_config", b"width_config"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Alert: _TypeAlias = Alert  # noqa: Y015
