"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from streamlit.proto import LabelVisibility_pb2 as _LabelVisibility_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class CameraInput(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    ID_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    FORM_ID_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    LABEL_VISIBILITY_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    label: _builtins.str
    help: _builtins.str
    form_id: _builtins.str
    disabled: _builtins.bool
    @_builtins.property
    def label_visibility(self) -> _LabelVisibility_pb2.LabelVisibility: ...
    def __init__(
        self,
        *,
        id: _builtins.str = ...,
        label: _builtins.str = ...,
        help: _builtins.str = ...,
        form_id: _builtins.str = ...,
        disabled: _builtins.bool = ...,
        label_visibility: _LabelVisibility_pb2.LabelVisibility | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["label_visibility", b"label_visibility"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["disabled", b"disabled", "form_id", b"form_id", "help", b"help", "id", b"id", "label", b"label", "label_visibility", b"label_visibility"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CameraInput: _TypeAlias = CameraInput  # noqa: Y015
