"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
The OpenMetrics protobuf schema which defines the protobuf wire format.
Ensure to interpret "required" as semantically required for a valid message.
All string fields MUST be UTF-8 encoded strings.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

class _MetricType:
    ValueType = _typing.NewType("ValueType", _builtins.int)
    V: _TypeAlias = ValueType  # noqa: Y015

class _MetricTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[_MetricType.ValueType], _builtins.type):
    DESCRIPTOR: _descriptor.EnumDescriptor
    UNKNOWN: _MetricType.ValueType  # 0
    """Unknown must use unknown MetricPoint values."""
    GAUGE: _MetricType.ValueType  # 1
    """Gauge must use gauge MetricPoint values."""
    COUNTER: _MetricType.ValueType  # 2
    """Counter must use counter MetricPoint values."""
    STATE_SET: _MetricType.ValueType  # 3
    """State set must use state set MetricPoint values."""
    INFO: _MetricType.ValueType  # 4
    """Info must use info MetricPoint values."""
    HISTOGRAM: _MetricType.ValueType  # 5
    """Histogram must use histogram value MetricPoint values."""
    GAUGE_HISTOGRAM: _MetricType.ValueType  # 6
    """Gauge histogram must use histogram value MetricPoint values."""
    SUMMARY: _MetricType.ValueType  # 7
    """Summary quantiles must use summary value MetricPoint values."""

class MetricType(_MetricType, metaclass=_MetricTypeEnumTypeWrapper):
    """The type of a Metric."""

UNKNOWN: MetricType.ValueType  # 0
"""Unknown must use unknown MetricPoint values."""
GAUGE: MetricType.ValueType  # 1
"""Gauge must use gauge MetricPoint values."""
COUNTER: MetricType.ValueType  # 2
"""Counter must use counter MetricPoint values."""
STATE_SET: MetricType.ValueType  # 3
"""State set must use state set MetricPoint values."""
INFO: MetricType.ValueType  # 4
"""Info must use info MetricPoint values."""
HISTOGRAM: MetricType.ValueType  # 5
"""Histogram must use histogram value MetricPoint values."""
GAUGE_HISTOGRAM: MetricType.ValueType  # 6
"""Gauge histogram must use histogram value MetricPoint values."""
SUMMARY: MetricType.ValueType  # 7
"""Summary quantiles must use summary value MetricPoint values."""
Global___MetricType: _TypeAlias = MetricType  # noqa: Y015

@_typing.final
class MetricSet(_message.Message):
    """The top-level container type that is encoded and sent over the wire."""

    DESCRIPTOR: _descriptor.Descriptor

    METRIC_FAMILIES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def metric_families(self) -> _containers.RepeatedCompositeFieldContainer[Global___MetricFamily]:
        """Each MetricFamily has one or more MetricPoints for a single Metric."""

    def __init__(
        self,
        *,
        metric_families: _abc.Iterable[Global___MetricFamily] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["metric_families", b"metric_families"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MetricSet: _TypeAlias = MetricSet  # noqa: Y015

@_typing.final
class MetricFamily(_message.Message):
    """One or more Metrics for a single MetricFamily, where each Metric
    has one or more MetricPoints.
    """

    DESCRIPTOR: _descriptor.Descriptor

    NAME_FIELD_NUMBER: _builtins.int
    TYPE_FIELD_NUMBER: _builtins.int
    UNIT_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    METRICS_FIELD_NUMBER: _builtins.int
    name: _builtins.str
    """Required."""
    type: Global___MetricType.ValueType
    """Optional."""
    unit: _builtins.str
    """Optional."""
    help: _builtins.str
    """Optional."""
    @_builtins.property
    def metrics(self) -> _containers.RepeatedCompositeFieldContainer[Global___Metric]:
        """Optional."""

    def __init__(
        self,
        *,
        name: _builtins.str = ...,
        type: Global___MetricType.ValueType = ...,
        unit: _builtins.str = ...,
        help: _builtins.str = ...,
        metrics: _abc.Iterable[Global___Metric] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["help", b"help", "metrics", b"metrics", "name", b"name", "type", b"type", "unit", b"unit"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MetricFamily: _TypeAlias = MetricFamily  # noqa: Y015

@_typing.final
class Metric(_message.Message):
    """A single metric with a unique set of labels within a metric family."""

    DESCRIPTOR: _descriptor.Descriptor

    LABELS_FIELD_NUMBER: _builtins.int
    METRIC_POINTS_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def labels(self) -> _containers.RepeatedCompositeFieldContainer[Global___Label]:
        """Optional."""

    @_builtins.property
    def metric_points(self) -> _containers.RepeatedCompositeFieldContainer[Global___MetricPoint]:
        """Optional."""

    def __init__(
        self,
        *,
        labels: _abc.Iterable[Global___Label] | None = ...,
        metric_points: _abc.Iterable[Global___MetricPoint] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["labels", b"labels", "metric_points", b"metric_points"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Metric: _TypeAlias = Metric  # noqa: Y015

@_typing.final
class Label(_message.Message):
    """A name-value pair. These are used in multiple places: identifying
    timeseries, value of INFO metrics, and exemplars in Histograms.
    """

    DESCRIPTOR: _descriptor.Descriptor

    NAME_FIELD_NUMBER: _builtins.int
    VALUE_FIELD_NUMBER: _builtins.int
    name: _builtins.str
    """Required."""
    value: _builtins.str
    """Required."""
    def __init__(
        self,
        *,
        name: _builtins.str = ...,
        value: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["name", b"name", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Label: _TypeAlias = Label  # noqa: Y015

@_typing.final
class MetricPoint(_message.Message):
    """A MetricPoint in a Metric."""

    DESCRIPTOR: _descriptor.Descriptor

    UNKNOWN_VALUE_FIELD_NUMBER: _builtins.int
    GAUGE_VALUE_FIELD_NUMBER: _builtins.int
    COUNTER_VALUE_FIELD_NUMBER: _builtins.int
    HISTOGRAM_VALUE_FIELD_NUMBER: _builtins.int
    STATE_SET_VALUE_FIELD_NUMBER: _builtins.int
    INFO_VALUE_FIELD_NUMBER: _builtins.int
    SUMMARY_VALUE_FIELD_NUMBER: _builtins.int
    TIMESTAMP_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def unknown_value(self) -> Global___UnknownValue: ...
    @_builtins.property
    def gauge_value(self) -> Global___GaugeValue: ...
    @_builtins.property
    def counter_value(self) -> Global___CounterValue: ...
    @_builtins.property
    def histogram_value(self) -> Global___HistogramValue: ...
    @_builtins.property
    def state_set_value(self) -> Global___StateSetValue: ...
    @_builtins.property
    def info_value(self) -> Global___InfoValue: ...
    @_builtins.property
    def summary_value(self) -> Global___SummaryValue: ...
    @_builtins.property
    def timestamp(self) -> _timestamp_pb2.Timestamp:
        """Optional."""

    def __init__(
        self,
        *,
        unknown_value: Global___UnknownValue | None = ...,
        gauge_value: Global___GaugeValue | None = ...,
        counter_value: Global___CounterValue | None = ...,
        histogram_value: Global___HistogramValue | None = ...,
        state_set_value: Global___StateSetValue | None = ...,
        info_value: Global___InfoValue | None = ...,
        summary_value: Global___SummaryValue | None = ...,
        timestamp: _timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["counter_value", b"counter_value", "gauge_value", b"gauge_value", "histogram_value", b"histogram_value", "info_value", b"info_value", "state_set_value", b"state_set_value", "summary_value", b"summary_value", "timestamp", b"timestamp", "unknown_value", b"unknown_value", "value", b"value"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["counter_value", b"counter_value", "gauge_value", b"gauge_value", "histogram_value", b"histogram_value", "info_value", b"info_value", "state_set_value", b"state_set_value", "summary_value", b"summary_value", "timestamp", b"timestamp", "unknown_value", b"unknown_value", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_value: _TypeAlias = _typing.Literal["unknown_value", "gauge_value", "counter_value", "histogram_value", "state_set_value", "info_value", "summary_value"]  # noqa: Y015
    _WhichOneofArgType_value: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_value) -> _WhichOneofReturnType_value | None: ...

Global___MetricPoint: _TypeAlias = MetricPoint  # noqa: Y015

@_typing.final
class UnknownValue(_message.Message):
    """Value for UNKNOWN MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    DOUBLE_VALUE_FIELD_NUMBER: _builtins.int
    INT_VALUE_FIELD_NUMBER: _builtins.int
    double_value: _builtins.float
    int_value: _builtins.int
    def __init__(
        self,
        *,
        double_value: _builtins.float = ...,
        int_value: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["double_value", b"double_value", "int_value", b"int_value", "value", b"value"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["double_value", b"double_value", "int_value", b"int_value", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_value: _TypeAlias = _typing.Literal["double_value", "int_value"]  # noqa: Y015
    _WhichOneofArgType_value: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_value) -> _WhichOneofReturnType_value | None: ...

Global___UnknownValue: _TypeAlias = UnknownValue  # noqa: Y015

@_typing.final
class GaugeValue(_message.Message):
    """Value for GAUGE MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    DOUBLE_VALUE_FIELD_NUMBER: _builtins.int
    INT_VALUE_FIELD_NUMBER: _builtins.int
    double_value: _builtins.float
    int_value: _builtins.int
    def __init__(
        self,
        *,
        double_value: _builtins.float = ...,
        int_value: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["double_value", b"double_value", "int_value", b"int_value", "value", b"value"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["double_value", b"double_value", "int_value", b"int_value", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_value: _TypeAlias = _typing.Literal["double_value", "int_value"]  # noqa: Y015
    _WhichOneofArgType_value: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_value) -> _WhichOneofReturnType_value | None: ...

Global___GaugeValue: _TypeAlias = GaugeValue  # noqa: Y015

@_typing.final
class CounterValue(_message.Message):
    """Value for COUNTER MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    DOUBLE_VALUE_FIELD_NUMBER: _builtins.int
    INT_VALUE_FIELD_NUMBER: _builtins.int
    CREATED_FIELD_NUMBER: _builtins.int
    EXEMPLAR_FIELD_NUMBER: _builtins.int
    double_value: _builtins.float
    int_value: _builtins.int
    @_builtins.property
    def created(self) -> _timestamp_pb2.Timestamp:
        """The time values began being collected for this counter.
        Optional.
        """

    @_builtins.property
    def exemplar(self) -> Global___Exemplar:
        """Optional."""

    def __init__(
        self,
        *,
        double_value: _builtins.float = ...,
        int_value: _builtins.int = ...,
        created: _timestamp_pb2.Timestamp | None = ...,
        exemplar: Global___Exemplar | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["created", b"created", "double_value", b"double_value", "exemplar", b"exemplar", "int_value", b"int_value", "total", b"total"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["created", b"created", "double_value", b"double_value", "exemplar", b"exemplar", "int_value", b"int_value", "total", b"total"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_total: _TypeAlias = _typing.Literal["double_value", "int_value"]  # noqa: Y015
    _WhichOneofArgType_total: _TypeAlias = _typing.Literal["total", b"total"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_total) -> _WhichOneofReturnType_total | None: ...

Global___CounterValue: _TypeAlias = CounterValue  # noqa: Y015

@_typing.final
class HistogramValue(_message.Message):
    """Value for HISTOGRAM or GAUGE_HISTOGRAM MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class Bucket(_message.Message):
        """Bucket is the number of values for a bucket in the histogram
        with an optional exemplar.
        """

        DESCRIPTOR: _descriptor.Descriptor

        COUNT_FIELD_NUMBER: _builtins.int
        UPPER_BOUND_FIELD_NUMBER: _builtins.int
        EXEMPLAR_FIELD_NUMBER: _builtins.int
        count: _builtins.int
        """Required."""
        upper_bound: _builtins.float
        """Optional."""
        @_builtins.property
        def exemplar(self) -> Global___Exemplar:
            """Optional."""

        def __init__(
            self,
            *,
            count: _builtins.int = ...,
            upper_bound: _builtins.float = ...,
            exemplar: Global___Exemplar | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["exemplar", b"exemplar"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["count", b"count", "exemplar", b"exemplar", "upper_bound", b"upper_bound"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    DOUBLE_VALUE_FIELD_NUMBER: _builtins.int
    INT_VALUE_FIELD_NUMBER: _builtins.int
    COUNT_FIELD_NUMBER: _builtins.int
    CREATED_FIELD_NUMBER: _builtins.int
    BUCKETS_FIELD_NUMBER: _builtins.int
    double_value: _builtins.float
    int_value: _builtins.int
    count: _builtins.int
    """Optional."""
    @_builtins.property
    def created(self) -> _timestamp_pb2.Timestamp:
        """The time values began being collected for this histogram.
        Optional.
        """

    @_builtins.property
    def buckets(self) -> _containers.RepeatedCompositeFieldContainer[Global___HistogramValue.Bucket]:
        """Optional."""

    def __init__(
        self,
        *,
        double_value: _builtins.float = ...,
        int_value: _builtins.int = ...,
        count: _builtins.int = ...,
        created: _timestamp_pb2.Timestamp | None = ...,
        buckets: _abc.Iterable[Global___HistogramValue.Bucket] | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["created", b"created", "double_value", b"double_value", "int_value", b"int_value", "sum", b"sum"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["buckets", b"buckets", "count", b"count", "created", b"created", "double_value", b"double_value", "int_value", b"int_value", "sum", b"sum"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_sum: _TypeAlias = _typing.Literal["double_value", "int_value"]  # noqa: Y015
    _WhichOneofArgType_sum: _TypeAlias = _typing.Literal["sum", b"sum"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_sum) -> _WhichOneofReturnType_sum | None: ...

Global___HistogramValue: _TypeAlias = HistogramValue  # noqa: Y015

@_typing.final
class Exemplar(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    VALUE_FIELD_NUMBER: _builtins.int
    TIMESTAMP_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    value: _builtins.float
    """Required."""
    @_builtins.property
    def timestamp(self) -> _timestamp_pb2.Timestamp:
        """Optional."""

    @_builtins.property
    def label(self) -> _containers.RepeatedCompositeFieldContainer[Global___Label]:
        """Labels are additional information about the exemplar value (e.g. trace id).
        Optional.
        """

    def __init__(
        self,
        *,
        value: _builtins.float = ...,
        timestamp: _timestamp_pb2.Timestamp | None = ...,
        label: _abc.Iterable[Global___Label] | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["timestamp", b"timestamp"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["label", b"label", "timestamp", b"timestamp", "value", b"value"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Exemplar: _TypeAlias = Exemplar  # noqa: Y015

@_typing.final
class StateSetValue(_message.Message):
    """Value for STATE_SET MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class State(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ENABLED_FIELD_NUMBER: _builtins.int
        NAME_FIELD_NUMBER: _builtins.int
        enabled: _builtins.bool
        """Required."""
        name: _builtins.str
        """Required."""
        def __init__(
            self,
            *,
            enabled: _builtins.bool = ...,
            name: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["enabled", b"enabled", "name", b"name"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    STATES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def states(self) -> _containers.RepeatedCompositeFieldContainer[Global___StateSetValue.State]:
        """Optional."""

    def __init__(
        self,
        *,
        states: _abc.Iterable[Global___StateSetValue.State] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["states", b"states"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___StateSetValue: _TypeAlias = StateSetValue  # noqa: Y015

@_typing.final
class InfoValue(_message.Message):
    """Value for INFO MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    INFO_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def info(self) -> _containers.RepeatedCompositeFieldContainer[Global___Label]:
        """Optional."""

    def __init__(
        self,
        *,
        info: _abc.Iterable[Global___Label] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["info", b"info"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InfoValue: _TypeAlias = InfoValue  # noqa: Y015

@_typing.final
class SummaryValue(_message.Message):
    """Value for SUMMARY MetricPoint."""

    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class Quantile(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        QUANTILE_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        quantile: _builtins.float
        """Required."""
        value: _builtins.float
        """Required."""
        def __init__(
            self,
            *,
            quantile: _builtins.float = ...,
            value: _builtins.float = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["quantile", b"quantile", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    DOUBLE_VALUE_FIELD_NUMBER: _builtins.int
    INT_VALUE_FIELD_NUMBER: _builtins.int
    COUNT_FIELD_NUMBER: _builtins.int
    CREATED_FIELD_NUMBER: _builtins.int
    QUANTILE_FIELD_NUMBER: _builtins.int
    double_value: _builtins.float
    int_value: _builtins.int
    count: _builtins.int
    """Optional."""
    @_builtins.property
    def created(self) -> _timestamp_pb2.Timestamp:
        """The time sum and count values began being collected for this summary.
        Optional.
        """

    @_builtins.property
    def quantile(self) -> _containers.RepeatedCompositeFieldContainer[Global___SummaryValue.Quantile]:
        """Optional."""

    def __init__(
        self,
        *,
        double_value: _builtins.float = ...,
        int_value: _builtins.int = ...,
        count: _builtins.int = ...,
        created: _timestamp_pb2.Timestamp | None = ...,
        quantile: _abc.Iterable[Global___SummaryValue.Quantile] | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["created", b"created", "double_value", b"double_value", "int_value", b"int_value", "sum", b"sum"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["count", b"count", "created", b"created", "double_value", b"double_value", "int_value", b"int_value", "quantile", b"quantile", "sum", b"sum"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_sum: _TypeAlias = _typing.Literal["double_value", "int_value"]  # noqa: Y015
    _WhichOneofArgType_sum: _TypeAlias = _typing.Literal["sum", b"sum"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_sum) -> _WhichOneofReturnType_sum | None: ...

Global___SummaryValue: _TypeAlias = SummaryValue  # noqa: Y015
