"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import LabelVisibility_pb2 as _LabelVisibility_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class ButtonGroup(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _ClickMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ClickModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[ButtonGroup._ClickMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SINGLE_SELECT: ButtonGroup._ClickMode.ValueType  # 0
        MULTI_SELECT: ButtonGroup._ClickMode.ValueType  # 1

    class ClickMode(_ClickMode, metaclass=_ClickModeEnumTypeWrapper): ...
    SINGLE_SELECT: ButtonGroup.ClickMode.ValueType  # 0
    MULTI_SELECT: ButtonGroup.ClickMode.ValueType  # 1

    class _Style:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _StyleEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[ButtonGroup._Style.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SEGMENTED_CONTROL: ButtonGroup._Style.ValueType  # 0
        PILLS: ButtonGroup._Style.ValueType  # 1

    class Style(_Style, metaclass=_StyleEnumTypeWrapper): ...
    SEGMENTED_CONTROL: ButtonGroup.Style.ValueType  # 0
    PILLS: ButtonGroup.Style.ValueType  # 1

    @_typing.final
    class Option(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CONTENT_FIELD_NUMBER: _builtins.int
        CONTENT_ICON_FIELD_NUMBER: _builtins.int
        content: _builtins.str
        content_icon: _builtins.str
        """when set, this is the icon that will be displayed next to the option"""
        def __init__(
            self,
            *,
            content: _builtins.str = ...,
            content_icon: _builtins.str | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_content_icon", b"_content_icon", "content_icon", b"content_icon"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_content_icon", b"_content_icon", "content", b"content", "content_icon", b"content_icon"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__content_icon: _TypeAlias = _typing.Literal["content_icon"]  # noqa: Y015
        _WhichOneofArgType__content_icon: _TypeAlias = _typing.Literal["_content_icon", b"_content_icon"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__content_icon) -> _WhichOneofReturnType__content_icon | None: ...

    ID_FIELD_NUMBER: _builtins.int
    OPTIONS_FIELD_NUMBER: _builtins.int
    DEFAULT_FIELD_NUMBER: _builtins.int
    DISABLED_FIELD_NUMBER: _builtins.int
    CLICK_MODE_FIELD_NUMBER: _builtins.int
    FORM_ID_FIELD_NUMBER: _builtins.int
    SET_VALUE_FIELD_NUMBER: _builtins.int
    STYLE_FIELD_NUMBER: _builtins.int
    LABEL_FIELD_NUMBER: _builtins.int
    LABEL_VISIBILITY_FIELD_NUMBER: _builtins.int
    HELP_FIELD_NUMBER: _builtins.int
    RAW_VALUES_FIELD_NUMBER: _builtins.int
    QUERY_PARAM_KEY_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    disabled: _builtins.bool
    click_mode: Global___ButtonGroup.ClickMode.ValueType
    form_id: _builtins.str
    set_value: _builtins.bool
    style: Global___ButtonGroup.Style.ValueType
    label: _builtins.str
    help: _builtins.str
    query_param_key: _builtins.str
    """If set, widget value is bound to this query parameter key"""
    @_builtins.property
    def options(self) -> _containers.RepeatedCompositeFieldContainer[Global___ButtonGroup.Option]: ...
    @_builtins.property
    def default(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]:
        """default is an array of indexes that are selected by default"""

    @_builtins.property
    def label_visibility(self) -> _LabelVisibility_pb2.LabelVisibility: ...
    @_builtins.property
    def raw_values(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]:
        """For multi-select mode, this contains all selected option strings.
        For single-select mode, this contains at most one selected option string.
        """

    def __init__(
        self,
        *,
        id: _builtins.str = ...,
        options: _abc.Iterable[Global___ButtonGroup.Option] | None = ...,
        default: _abc.Iterable[_builtins.int] | None = ...,
        disabled: _builtins.bool = ...,
        click_mode: Global___ButtonGroup.ClickMode.ValueType = ...,
        form_id: _builtins.str = ...,
        set_value: _builtins.bool = ...,
        style: Global___ButtonGroup.Style.ValueType = ...,
        label: _builtins.str = ...,
        label_visibility: _LabelVisibility_pb2.LabelVisibility | None = ...,
        help: _builtins.str | None = ...,
        raw_values: _abc.Iterable[_builtins.str] | None = ...,
        query_param_key: _builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_help", b"_help", "_query_param_key", b"_query_param_key", "help", b"help", "label_visibility", b"label_visibility", "query_param_key", b"query_param_key"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_help", b"_help", "_query_param_key", b"_query_param_key", "click_mode", b"click_mode", "default", b"default", "disabled", b"disabled", "form_id", b"form_id", "help", b"help", "id", b"id", "label", b"label", "label_visibility", b"label_visibility", "options", b"options", "query_param_key", b"query_param_key", "raw_values", b"raw_values", "set_value", b"set_value", "style", b"style"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__help: _TypeAlias = _typing.Literal["help"]  # noqa: Y015
    _WhichOneofArgType__help: _TypeAlias = _typing.Literal["_help", b"_help"]  # noqa: Y015
    _WhichOneofReturnType__query_param_key: _TypeAlias = _typing.Literal["query_param_key"]  # noqa: Y015
    _WhichOneofArgType__query_param_key: _TypeAlias = _typing.Literal["_query_param_key", b"_query_param_key"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__help) -> _WhichOneofReturnType__help | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__query_param_key) -> _WhichOneofReturnType__query_param_key | None: ...

Global___ButtonGroup: _TypeAlias = ButtonGroup  # noqa: Y015
