import{o as e}from"./chunk.DuxOD-Sk.js";import{r as t}from"./emotion-is-prop-valid.esm.DV_OErv-.js";import{c as n,l as r,t as i}from"./emotion-styled.browser.esm.CEYoudG7.js";import"./loglevel.H4SN4KQm.js";import"./isLength.Dot76Eow.js";import"./getColors.Llt-1DRT.js";import"./protobuf.GnXEZo24.js";import{xt as a}from"./src.CIyydb94.js";import"./utils.C1Nidt8_.js";import"./utils.VFl7c69J.js";import"./ErrorElement.K-kvHExv.js";import"./v4.C6ecLp5d.js";import"./utils.B6lSy2ZF.js";import"./UriUtil.BJr0dLQG.js";import"./useCopyToClipboard.CUBg6ZxJ.js";import"./useWindowDimensionsContext.jnKliU5K.js";import"./katex.min.DyoqhKgf.js";import{t as o}from"./ProgressBar.Bg7j5j5V.js";var s=e(t()),c=i(`div`,{target:`e1jwj65h0`})(({theme:e})=>({paddingBottom:e.spacing.sm,lineHeight:`normal`}));function l({element:e}){return r(`div`,{className:`stProgress`,"data-testid":`stProgress`,children:[n(c,{children:n(a,{source:e.text,allowHTML:!1,isLabel:!0})}),n(o,{value:e.value})]})}var u=(0,s.memo)(l);export{u as default};