"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from streamlit.proto import ArrowData_pb2 as _ArrowData_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class Table(_message.Message):
    """Proto message for st.table element."""

    DESCRIPTOR: _descriptor.Descriptor

    class _BorderMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _BorderModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[Table._BorderMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        ALL: Table._BorderMode.ValueType  # 0
        """Show borders around the table and between cells."""
        NONE: Table._BorderMode.ValueType  # 1
        """Show no borders."""
        HORIZONTAL: Table._BorderMode.ValueType  # 2
        """Show only horizontal borders between rows."""

    class BorderMode(_BorderMode, metaclass=_BorderModeEnumTypeWrapper):
        """Available border modes:"""

    ALL: Table.BorderMode.ValueType  # 0
    """Show borders around the table and between cells."""
    NONE: Table.BorderMode.ValueType  # 1
    """Show no borders."""
    HORIZONTAL: Table.BorderMode.ValueType  # 2
    """Show only horizontal borders between rows."""

    ARROW_DATA_FIELD_NUMBER: _builtins.int
    BORDER_MODE_FIELD_NUMBER: _builtins.int
    HIDE_INDEX_FIELD_NUMBER: _builtins.int
    HIDE_HEADER_FIELD_NUMBER: _builtins.int
    border_mode: Global___Table.BorderMode.ValueType
    """How to show borders around the table and between cells."""
    hide_index: _builtins.bool
    """Whether to hide the index column(s)."""
    hide_header: _builtins.bool
    """Whether to hide the column header row(s)."""
    @_builtins.property
    def arrow_data(self) -> _ArrowData_pb2.ArrowData:
        """The Arrow data to display"""

    def __init__(
        self,
        *,
        arrow_data: _ArrowData_pb2.ArrowData | None = ...,
        border_mode: Global___Table.BorderMode.ValueType = ...,
        hide_index: _builtins.bool = ...,
        hide_header: _builtins.bool = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["arrow_data", b"arrow_data"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["arrow_data", b"arrow_data", "border_mode", b"border_mode", "hide_header", b"hide_header", "hide_index", b"hide_index"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Table: _TypeAlias = Table  # noqa: Y015
