"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
*!
Copyright (c) Streamlit Inc. (2018-2022) Snowflake Inc. (2022-2026)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class ArrowData(_message.Message):
    """Arrow data buffer with optional styling. Use this message for serialized
    Arrow data, with optional pandas styling for table-like displays.
    """

    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class PandasStyler(_message.Message):
        """Pandas Styler information for formatting and styling table displays."""

        DESCRIPTOR: _descriptor.Descriptor

        UUID_FIELD_NUMBER: _builtins.int
        CAPTION_FIELD_NUMBER: _builtins.int
        STYLES_FIELD_NUMBER: _builtins.int
        DISPLAY_VALUES_FIELD_NUMBER: _builtins.int
        uuid: _builtins.str
        """The Styler's source UUID (if the user provided one), or the path-based
        hash that we generate (if no source UUID was provided).
        """
        caption: _builtins.str
        """The table's caption."""
        styles: _builtins.str
        """`styles` contains the CSS for the entire source table."""
        display_values: _builtins.bytes
        """display_values is another Arrow/Table: a copy of the source table, but
        with all the display values formatted to the user-specified rules.
        """
        def __init__(
            self,
            *,
            uuid: _builtins.str = ...,
            caption: _builtins.str = ...,
            styles: _builtins.str = ...,
            display_values: _builtins.bytes = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["caption", b"caption", "display_values", b"display_values", "styles", b"styles", "uuid", b"uuid"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    DATA_FIELD_NUMBER: _builtins.int
    STYLER_FIELD_NUMBER: _builtins.int
    data: _builtins.bytes
    """The serialized Apache Arrow buffer (IPC stream or file format bytes)"""
    @_builtins.property
    def styler(self) -> Global___ArrowData.PandasStyler:
        """Optional pandas styler information (used by table-like displays)"""

    def __init__(
        self,
        *,
        data: _builtins.bytes = ...,
        styler: Global___ArrowData.PandasStyler | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["styler", b"styler"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["data", b"data", "styler", b"styler"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ArrowData: _TypeAlias = ArrowData  # noqa: Y015
